@@ -18,10 +18,10 @@
  *    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <QtTest/QTest>
+#include <QTest>
 #include <limits>
 
-#include <bytearraymodel.h>
+#include <okteta/bytearraymodel.h>
 
 #include "view/structures/datatypes/array/arraydatainformation.h"
 #include "view/structures/datatypes/array/primitivearraydata.h"
